IngeoML
=====================
.. image:: https://github.com/INGEOTEC/IngeoML/actions/workflows/test.yaml/badge.svg
		:target: https://github.com/INGEOTEC/IngeoML/actions/workflows/test.yaml

.. image:: https://coveralls.io/repos/github/INGEOTEC/IngeoML/badge.svg?branch=develop
		:target: https://coveralls.io/github/INGEOTEC/IngeoML?branch=develop

.. image:: https://badge.fury.io/py/IngeoML.svg
		:target: https://badge.fury.io/py/IngeoML

.. image:: https://readthedocs.org/projects/ingeoml/badge/?version=latest
    :target: https://ingeoml.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Machine Learning Tools
